@@ -39,9 +39,13 @@
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
-using namespace synfig;
-using namespace std;
-using namespace etl;
+namespace synfig
+{
+namespace modules
+{
+namespace lyr_std
+{
+
 class InsideOut_Trans;
 
 class InsideOut : public Layer
@@ -60,11 +64,18 @@ public:
 	virtual ValueBase get_param(const String &param)const;
 	virtual Color get_color(Context context, const Point &pos)const;
 	virtual CairoColor get_cairocolor(Context context, const Point &pos)const;
-	synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
+	Layer::Handle hit_check(Context context, const Point &point)const;
 	virtual Vocab get_param_vocab()const;
-	virtual etl::handle<synfig::Transform> get_transform()const;
+	virtual etl::handle<Transform> get_transform()const;
+
+protected:
+	virtual RendDesc get_sub_renddesc_vfunc(const RendDesc &renddesc) const;
 };
 
+}; // END of namespace lyr_std
+}; // END of namespace modules
+}; // END of namespace synfig
+
 /* === E N D =============================================================== */
 
 #endif
