@@ -40,9 +40,13 @@
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
-using namespace synfig;
-using namespace std;
-using namespace etl;
+namespace synfig
+{
+namespace modules
+{
+namespace lyr_std
+{
+
 class Rotate_Trans;
 
 class Rotate : public Layer
@@ -61,18 +65,25 @@ public:
 	Rotate();
 	~Rotate();
 
-	virtual bool set_param(const synfig::String & param, const synfig::ValueBase &value);
-	virtual ValueBase get_param(const synfig::String & param)const;
+	virtual bool set_param(const String & param, const ValueBase &value);
+	virtual ValueBase get_param(const String & param)const;
 	virtual Color get_color(Context context, const Point &pos)const;
 	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
 	virtual bool accelerated_cairorender(Context context, cairo_t *cr, int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
-	synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
+	Layer::Handle hit_check(Context context, const Point &point)const;
 	virtual Vocab get_param_vocab()const;
 	virtual Rect get_full_bounding_rect(Context context)const;
 
-	virtual etl::handle<synfig::Transform> get_transform()const;
+	virtual etl::handle<Transform> get_transform()const;
+
+protected:
+	virtual rendering::Task::Handle build_rendering_task_vfunc(Context context)const;
 };
 
+}; // END of namespace lyr_std
+}; // END of namespace modules
+}; // END of namespace synfig
+
 /* === E N D =============================================================== */
 
 #endif
