@@ -31,8 +31,16 @@
 #	include <config.h>
 #endif
 
+#include <cstring>
+
+#include <ETL/pen>
+#include <ETL/misc>
+
 #include "shade.h"
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -44,15 +52,19 @@
 #include <synfig/segment.h>
 #include <synfig/cairo_renddesc.h>
 
-#include <cstring>
-#include <ETL/pen>
-#include <ETL/misc>
+#include <synfig/rendering/primitive/affinetransformation.h>
+
+#include <synfig/rendering/common/task/taskblur.h>
+#include <synfig/rendering/common/task/tasktransformation.h>
+#include <synfig/rendering/common/task/taskpixelcolormatrix.h>
 
 #endif
 
-using namespace synfig;
-using namespace etl;
 using namespace std;
+using namespace etl;
+using namespace synfig;
+using namespace modules;
+using namespace lyr_std;
 
 /*#define TYPE_BOX			0
 #define TYPE_FASTGUASSIAN	1
@@ -72,14 +84,14 @@ SYNFIG_LAYER_SET_CVS_ID(Layer_Shade,"$Id$");
 
 /* -- F U N C T I O N S ----------------------------------------------------- */
 
-inline void clamp(synfig::Vector &v)
+inline void clamp(Vector &v)
 {
 	if(v[0]<0.0)v[0]=0.0;
 	if(v[1]<0.0)v[1]=0.0;
 }
 
 Layer_Shade::Layer_Shade():
-	Layer_Composite	(0.75,Color::BLEND_BEHIND),
+	Layer_CompositeFork(0.75,Color::BLEND_BEHIND),
 	param_size(ValueBase(Vector(0.1,0.1))),
 	param_type(ValueBase(int(Blur::FASTGAUSSIAN))),
 	param_color(ValueBase(Color::black())),
@@ -95,7 +107,7 @@ Layer_Shade::set_param(const String &param, const ValueBase &value)
 {
 	IMPORT_VALUE_PLUS(param_size,
 		{
-			synfig::Vector size=param_size.get(synfig::Vector());
+			Vector size=param_size.get(Vector());
 			clamp(size);
 			param_size.set(size);
 		}
@@ -103,7 +115,7 @@ Layer_Shade::set_param(const String &param, const ValueBase &value)
 	IMPORT_VALUE(param_type);
 	IMPORT_VALUE_PLUS(param_color,
 		{
-			synfig::Color color=param_color.get(synfig::Color());
+			Color color=param_color.get(Color());
 			if (color.get_a() == 0)
 			{
 				if (converted_blend_)
@@ -144,10 +156,10 @@ Layer_Shade::get_param(const String &param)const
 Color
 Layer_Shade::get_color(Context context, const Point &pos)const
 {
-	synfig::Vector size=param_size.get(synfig::Vector());
+	Vector size=param_size.get(Vector());
 	int type=param_type.get(int());
-	synfig::Color color=param_color.get(synfig::Color());
-	synfig::Vector origin=param_origin.get(synfig::Vector());
+	Color color=param_color.get(Color());
+	Vector origin=param_origin.get(Vector());
 	bool invert=param_invert.get(bool());
 	
 	Point blurpos = Blur(size,type)(pos);
@@ -170,10 +182,10 @@ Layer_Shade::accelerated_render(Context context,Surface *surface,int quality, co
 {
 	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
 
-	synfig::Vector size=param_size.get(synfig::Vector());
+	Vector size=param_size.get(Vector());
 	int type=param_type.get(int());
-	synfig::Color color=param_color.get(synfig::Color());
-	synfig::Vector origin=param_origin.get(synfig::Vector());
+	Color color=param_color.get(Color());
+	Vector origin=param_origin.get(Vector());
 	bool invert=param_invert.get(bool());
 
 	int x,y;
@@ -353,7 +365,7 @@ Layer_Shade::accelerated_render(Context context,Surface *surface,int quality, co
 
 		workdesc.clear_flags();
 		workdesc.set_wh(tmpw,tmph);
-		//synfig::info("fw: %d, fh: %d",fw,fh);
+		//info("fw: %d, fh: %d",fw,fh);
 
 		//render the blur fodder
 		if(!context.accelerated_render(&worksurface,quality,workdesc,&stageone))
@@ -409,10 +421,10 @@ Layer_Shade::accelerated_render(Context context,Surface *surface,int quality, co
 bool
 Layer_Shade::accelerated_cairorender(Context context,cairo_t *cr, int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
-	synfig::Vector size=param_size.get(synfig::Vector());
+	Vector size=param_size.get(Vector());
 	int type=param_type.get(int());
-	synfig::Color color=param_color.get(synfig::Color());
-	synfig::Vector origin=param_origin.get(synfig::Vector());
+	Color color=param_color.get(Color());
+	Vector origin=param_origin.get(Vector());
 	bool invert=param_invert.get(bool());
 
 	int x,y;
@@ -559,7 +571,7 @@ Layer_Shade::accelerated_cairorender(Context context,cairo_t *cr, int quality, c
 	CairoSurface cairoworksurface(worksurface);
 	if(!cairoworksurface.map_cairo_image())
 	{
-		synfig::info("map cairo image failed");
+		info("map cairo image failed");
 		return false;
 	}
 	// Extract the alpha
@@ -651,8 +663,8 @@ Layer_Shade::get_param_vocab(void)const
 Rect
 Layer_Shade::get_full_bounding_rect(Context context)const
 {
-	synfig::Vector size=param_size.get(synfig::Vector());
-	synfig::Vector origin=param_origin.get(synfig::Vector());
+	Vector size=param_size.get(Vector());
+	Vector origin=param_origin.get(Vector());
 	bool invert=param_invert.get(bool());
 
 	if(is_disabled())
@@ -673,3 +685,36 @@ Layer_Shade::get_full_bounding_rect(Context context)const
 
 	return bounds|under;
 }
+
+rendering::Task::Handle
+Layer_Shade::build_composite_fork_task_vfunc(ContextParams /* context_params */, rendering::Task::Handle sub_task)const
+{
+	Vector size = param_size.get(Vector());
+	rendering::Blur::Type type = (rendering::Blur::Type)param_type.get(int());
+	Color color = param_color.get(Color());
+	Vector origin = param_origin.get(Vector());
+	bool invert = param_invert.get(bool());
+
+	rendering::TaskBlur::Handle task_blur(new rendering::TaskBlur());
+	task_blur->blur.size = size;
+	task_blur->blur.type = type;
+	task_blur->sub_task() = sub_task->clone_recursive();
+
+	ColorMatrix matrix;
+	matrix *= ColorMatrix().set_replace_color(color);
+	if (invert)
+		matrix *= ColorMatrix().set_invert_alpha();
+
+	rendering::TaskPixelColorMatrix::Handle task_colormatrix(new rendering::TaskPixelColorMatrix());
+	task_colormatrix->matrix = matrix;
+	task_colormatrix->sub_task() = task_blur;
+
+	rendering::AffineTransformation::Handle affine_transformation(new rendering::AffineTransformation());
+	affine_transformation->matrix.set_translate(origin);
+
+	rendering::TaskTransformation::Handle task_transformation(new rendering::TaskTransformation());
+	task_transformation->transformation = affine_transformation;
+	task_transformation->sub_task() = task_colormatrix;
+
+	return task_transformation;
+}
