@@ -28,7 +28,7 @@
 
 /* === H E A D E R S ======================================================= */
 
-#include <synfig/layers/layer_composite.h>
+#include <synfig/layer.h>
 #include <synfig/vector.h>
 #include <synfig/rect.h>
 
@@ -37,8 +37,14 @@
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
+
 namespace synfig
 {
+namespace modules
+{
+namespace lyr_std
+{
+
 class Spherize_Trans;
 
 class Layer_SphereDistort : public Layer
@@ -81,9 +87,14 @@ public:
 
 	virtual Vocab get_param_vocab()const;
 	virtual etl::handle<Transform> get_transform()const;
+
+protected:
+	virtual RendDesc get_sub_renddesc_vfunc(const RendDesc &renddesc) const;
 }; // END of class Layer_SphereDistort
 
-}
+}; // END of namespace lyr_std
+}; // END of namespace modules
+}; // END of namespace synfig
 
 /* === E N D =============================================================== */
 
