@@ -32,7 +32,9 @@
 #	include <config.h>
 #endif
 
-#include "translate.h"
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -44,8 +46,19 @@
 #include <synfig/canvas.h>
 #include <synfig/transform.h>
 
+#include "translate.h"
+
+#include <synfig/rendering/common/task/tasktransformation.h>
+#include <synfig/rendering/primitive/affinetransformation.h>
+
 #endif
 
+using namespace std;
+using namespace etl;
+using namespace synfig;
+using namespace modules;
+using namespace lyr_std;
+
 /* === M A C R O S ========================================================= */
 
 /* === G L O B A L S ======================================================= */
@@ -104,8 +117,8 @@ Translate::get_param_vocab()const
 	return ret;
 }
 
-synfig::Layer::Handle
-Translate::hit_check(synfig::Context context, const synfig::Point &pos)const
+Layer::Handle
+Translate::hit_check(Context context, const Point &pos)const
 {
 	Vector origin=param_origin.get(Vector());
 	return context.hit_check(pos-origin);
@@ -118,23 +131,23 @@ Translate::get_color(Context context, const Point &pos)const
 	return context.get_color(pos-origin);
 }
 
-class Translate_Trans : public Transform
+class lyr_std::Translate_Trans : public Transform
 {
 	etl::handle<const Translate> layer;
 public:
 	Translate_Trans(const Translate* x):Transform(x->get_guid()),layer(x) { }
 
-	synfig::Vector perform(const synfig::Vector& x)const
+	Vector perform(const Vector& x)const
 	{
 		return x+layer->param_origin.get(Vector());
 	}
 
-	synfig::Vector unperform(const synfig::Vector& x)const
+	Vector unperform(const Vector& x)const
 	{
 		return x-layer->param_origin.get(Vector());
 	}
 
-	synfig::String get_string()const
+	String get_string()const
 	{
 		return "translate";
 	}
@@ -191,3 +204,15 @@ Translate::get_full_bounding_rect(Context context)const
 	Vector origin=param_origin.get(Vector());
 	return context.get_full_bounding_rect() + origin;
 }
+
+
+rendering::Task::Handle
+Translate::build_rendering_task_vfunc(Context context)const
+{
+	rendering::TaskTransformation::Handle task_transformation(new rendering::TaskTransformation());
+	rendering::AffineTransformation::Handle affine_transformation(new rendering::AffineTransformation());
+	affine_transformation->matrix.set_translate(param_origin.get(Vector()));
+	task_transformation->transformation = affine_transformation;
+	task_transformation->sub_task() = context.build_rendering_task();
+	return task_transformation;
+}
