@@ -29,7 +29,7 @@
 
 /* === H E A D E R S ======================================================= */
 
-#include <synfig/layers/layer_composite.h>
+#include <synfig/layers/layer_composite_fork.h>
 #include <synfig/color.h>
 #include <synfig/vector.h>
 #include <synfig/value.h>
@@ -41,46 +41,62 @@
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
+
+namespace synfig
+{
+namespace modules
+{
+namespace lyr_std
+{
+
 class Twirl_Trans;
 
-class Twirl : public synfig::Layer_Composite
+class Twirl : public Layer_CompositeFork
 {
 	SYNFIG_LAYER_MODULE_EXT
 	friend class Twirl_Trans;
 
 private:
-	//! Parameter: (synfig::Point)
-	synfig::ValueBase param_center;
-	//! Parameter: (synfig::Real)
-	synfig::ValueBase param_radius;
-	//! Parameter: (synfig::Angle)
-	synfig::ValueBase param_rotations;
+	//! Parameter: (Point)
+	ValueBase param_center;
+	//! Parameter: (Real)
+	ValueBase param_radius;
+	//! Parameter: (Angle)
+	ValueBase param_rotations;
 	//! Parameter: (bool)
-	synfig::ValueBase param_distort_inside;
+	ValueBase param_distort_inside;
 	//! Parameter: (bool)
-	synfig::ValueBase param_distort_outside;
+	ValueBase param_distort_outside;
 
-	synfig::Point distort(const synfig::Point &pos, bool reverse=false)const;
+	Point distort(const Point &pos, bool reverse=false)const;
 public:
 
 	Twirl();
 
-	virtual bool set_param(const synfig::String & param, const synfig::ValueBase &value);
+	virtual bool set_param(const String & param, const ValueBase &value);
 
-	virtual synfig::ValueBase get_param(const synfig::String & param)const;
+	virtual ValueBase get_param(const String & param)const;
 
-	virtual synfig::Color get_color(synfig::Context context, const synfig::Point &pos)const;
-	virtual synfig::CairoColor get_cairocolor(synfig::Context context, const synfig::Point &pos)const;
+	virtual Color get_color(Context context, const Point &pos)const;
+	virtual CairoColor get_cairocolor(Context context, const Point &pos)const;
 
-	//virtual bool accelerated_render(synfig::Context context,synfig::Surface *surface,int quality, const synfig::RendDesc &renddesc, synfig::ProgressCallback *cb)const;
+	//virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
 
-	synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
+	Layer::Handle hit_check(Context context, const Point &point)const;
 
 	virtual Vocab get_param_vocab()const;
-	virtual etl::handle<synfig::Transform> get_transform()const;
+	virtual etl::handle<Transform> get_transform()const;
 	virtual bool reads_context()const { return true; }
+
+protected:
+	virtual RendDesc get_sub_renddesc_vfunc(const RendDesc &renddesc) const;
+	virtual rendering::Task::Handle build_rendering_task_vfunc(Context context) const;
 }; // END of class Twirl
 
+}; // END of namespace lyr_std
+}; // END of namespace modules
+}; // END of namespace synfig
+
 /* === E N D =============================================================== */
 
 #endif
