@@ -34,6 +34,10 @@
 #endif
 
 #include "warp.h"
+
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -48,6 +52,12 @@
 
 #endif
 
+using namespace std;
+using namespace etl;
+using namespace synfig;
+using namespace modules;
+using namespace lyr_std;
+
 /* === M A C R O S ========================================================= */
 
 /* === G L O B A L S ======================================================= */
@@ -424,20 +434,20 @@ Warp::get_param_vocab()const
 }
 
 
-class Warp_Trans : public Transform
+class lyr_std::Warp_Trans : public Transform
 {
 	etl::handle<const Warp> layer;
 public:
 	Warp_Trans(const Warp* x):Transform(x->get_guid()),layer(x) { }
 
-	synfig::Vector perform(const synfig::Vector& x)const
+	Vector perform(const Vector& x)const
 	{
 		return layer->transform_backward(x);
 		//Point pos(x-layer->origin);
 		//return Point(layer->cos_val*pos[0]-layer->sin_val*pos[1],layer->sin_val*pos[0]+layer->cos_val*pos[1])+layer->origin;
 	}
 
-	synfig::Vector unperform(const synfig::Vector& x)const
+	Vector unperform(const Vector& x)const
 	{
 
 		return layer->transform_forward(x);
@@ -445,7 +455,7 @@ public:
 		//return Point(layer->cos_val*pos[0]+layer->sin_val*pos[1],-layer->sin_val*pos[0]+layer->cos_val*pos[1])+layer->origin;
 	}
 
-	synfig::String get_string()const
+	String get_string()const
 	{
 		return "warp";
 	}
@@ -456,8 +466,8 @@ Warp::get_transform()const
 	return new Warp_Trans(this);
 }
 
-synfig::Layer::Handle
-Warp::hit_check(synfig::Context context, const synfig::Point &p)const
+Layer::Handle
+Warp::hit_check(Context context, const Point &p)const
 {
 	Point src_tl=param_src_tl.get(Point());
 	Point src_br=param_src_br.get(Point());
@@ -501,6 +511,149 @@ Warp::get_color(Context context, const Point &p)const
 
 //#define ACCEL_WARP_IS_BROKEN 1
 
+RendDesc
+Warp::get_sub_renddesc_vfunc(const RendDesc &renddesc) const
+{
+	Point dest_tl=param_dest_tl.get(Point());
+	Point dest_tr=param_dest_tr.get(Point());
+	Point dest_bl=param_dest_bl.get(Point());
+	Point dest_br=param_dest_br.get(Point());
+	Real horizon=param_horizon.get(Real());
+	bool clip=param_clip.get(bool());
+
+	Point tl(renddesc.get_tl());
+	Point br(renddesc.get_br());
+
+	Rect bounding_rect;
+
+	Rect render_rect(tl,br);
+	Rect clip_rect(Rect::full_plane());
+	Rect dest_rect(dest_tl,dest_br); dest_rect.expand(dest_tr).expand(dest_bl);
+
+	Real zoom_factor(1.0);
+
+	{
+		Rect other(render_rect);
+		if(clip)
+			other&=dest_rect;
+
+		Point min(other.get_min());
+		Point max(other.get_max());
+
+		bool init_point_set=false;
+
+		// Point trans_point[4];
+		Point p;
+		// Real trans_z[4];
+		Real z,minz(10000000000000.0f),maxz(0);
+
+		//! \todo checking the 4 corners for 0<=z<horizon*2 and using
+		//! only 4 corners which satisfy this condition isn't the
+		//! right thing to do.  It's possible that none of the 4
+		//! corners fall within that range, and yet content of the
+		//! tile does.
+		p=transform_forward(min);
+		z=transform_backward_z(p);
+		if(z>0 && z<horizon*2)
+		{
+			if(init_point_set)
+				bounding_rect.expand(p);
+			else
+				bounding_rect=Rect(p);
+			init_point_set=true;
+			maxz=std::max(maxz,z);
+			minz=std::min(minz,z);
+		}
+
+		p=transform_forward(max);
+		z=transform_backward_z(p);
+		if(z>0 && z<horizon*2)
+		{
+			if(init_point_set)
+				bounding_rect.expand(p);
+			else
+				bounding_rect=Rect(p);
+			init_point_set=true;
+			maxz=std::max(maxz,z);
+			minz=std::min(minz,z);
+		}
+
+		swap(min[1],max[1]);
+
+		p=transform_forward(min);
+		z=transform_backward_z(p);
+		if(z>0 && z<horizon*2)
+		{
+			if(init_point_set)
+				bounding_rect.expand(p);
+			else
+				bounding_rect=Rect(p);
+			init_point_set=true;
+			maxz=std::max(maxz,z);
+			minz=std::min(minz,z);
+		}
+
+		p=transform_forward(max);
+		z=transform_backward_z(p);
+		if(z>0 && z<horizon*2)
+		{
+			if(init_point_set)
+				bounding_rect.expand(p);
+			else
+				bounding_rect=Rect(p);
+			init_point_set=true;
+			maxz=std::max(maxz,z);
+			minz=std::min(minz,z);
+		}
+
+		zoom_factor=(1+(maxz-minz));
+
+	}
+
+	Point min_point(bounding_rect.get_min());
+	Point max_point(bounding_rect.get_max());
+
+	// we're going to divide by the difference of these pairs soon;
+	// if they're the same, we'll be dividing by zero, and we don't
+	// want to do that!
+	// \todo what should we do in this case?
+	if (min_point[0] == max_point[0]) max_point[0] += 0.001;
+	if (min_point[1] == max_point[1]) max_point[1] += 0.001;
+
+	if(tl[0]>br[0])
+	{
+		tl[0]=max_point[0];
+		br[0]=min_point[0];
+	}
+	else
+	{
+		br[0]=max_point[0];
+		tl[0]=min_point[0];
+	}
+	if(tl[1]>br[1])
+	{
+		tl[1]=max_point[1];
+		br[1]=min_point[1];
+	}
+	else
+	{
+		br[1]=max_point[1];
+		tl[1]=min_point[1];
+	}
+
+	const int tmp_d(max(renddesc.get_w(),renddesc.get_h()));
+	Real src_pw=(tmp_d*zoom_factor)/(br[0]-tl[0]);
+	Real src_ph=(tmp_d*zoom_factor)/(br[1]-tl[1]);
+
+	RendDesc desc(renddesc);
+	desc.clear_flags();
+	desc.set_tl(tl);
+	desc.set_br(br);
+	desc.set_wh(ceil_to_int(src_pw*(br[0]-tl[0])),ceil_to_int(src_ph*(br[1]-tl[1])));
+
+	return desc;
+}
+
 bool
 Warp::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
@@ -638,8 +791,8 @@ Warp::accelerated_render(Context context,Surface *surface,int quality, const Ren
 	;
 	swap(tl[1],br[1]);*/
 
-	//synfig::warning("given window: [%f,%f]-[%f,%f] %dx%d",tl[0],tl[1],br[0],br[1],renddesc.get_w(),renddesc.get_h());
-	//synfig::warning("Projected: [%f,%f]-[%f,%f]",bounding_rect.get_min()[0],bounding_rect.get_min()[1],bounding_rect.get_max()[0],bounding_rect.get_max()[1]);
+	//warning("given window: [%f,%f]-[%f,%f] %dx%d",tl[0],tl[1],br[0],br[1],renddesc.get_w(),renddesc.get_h());
+	//warning("Projected: [%f,%f]-[%f,%f]",bounding_rect.get_min()[0],bounding_rect.get_min()[1],bounding_rect.get_max()[0],bounding_rect.get_max()[1]);
 
 	// If we are clipping, then go ahead and clip to the
 	// source rectangle
@@ -697,7 +850,7 @@ Warp::accelerated_render(Context context,Surface *surface,int quality, const Ren
 	desc.set_br(br);
 	desc.set_wh(ceil_to_int(src_pw*(br[0]-tl[0])),ceil_to_int(src_ph*(br[1]-tl[1])));
 
-	//synfig::warning("surface to render: [%f,%f]-[%f,%f] %dx%d",desc.get_tl()[0],desc.get_tl()[1],desc.get_br()[0],desc.get_br()[1],desc.get_w(),desc.get_h());
+	//warning("surface to render: [%f,%f]-[%f,%f] %dx%d",desc.get_tl()[0],desc.get_tl()[1],desc.get_br()[0],desc.get_br()[1],desc.get_w(),desc.get_h());
 	if(desc.get_w()==0 && desc.get_h()==0)
 	{
 		surface->set_wh(renddesc.get_w(),renddesc.get_h());
@@ -742,7 +895,7 @@ Warp::accelerated_render(Context context,Surface *surface,int quality, const Ren
 				u=(tmp[0]-tl[0])*src_pw;
 				v=(tmp[1]-tl[1])*src_ph;
 
-				if(u<0 || v<0 || u>=source.get_w() || v>=source.get_h() || isnan(u) || isnan(v))
+				if(u<0 || v<0 || u>=source.get_w() || v>=source.get_h() || std::isnan(u) || std::isnan(v))
 					(*surface)[y][x]=context.get_color(tmp);
 				else
 					(*surface)[y][x]=source.cubic_sample(u,v);
@@ -776,7 +929,7 @@ Warp::accelerated_render(Context context,Surface *surface,int quality, const Ren
 				u=(tmp[0]-tl[0])*src_pw;
 				v=(tmp[1]-tl[1])*src_ph;
 
-				if(u<0 || v<0 || u>=source.get_w() || v>=source.get_h() || isnan(u) || isnan(v))
+				if(u<0 || v<0 || u>=source.get_w() || v>=source.get_h() || std::isnan(u) || std::isnan(v))
 					(*surface)[y][x]=context.get_color(tmp);
 				else
 					(*surface)[y][x]=source.linear_sample(u,v);
@@ -809,7 +962,7 @@ Warp::accelerated_render(Context context,Surface *surface,int quality, const Ren
 				u=(tmp[0]-tl[0])*src_pw;
 				v=(tmp[1]-tl[1])*src_ph;
 
-				if(u<0 || v<0 || u>=source.get_w() || v>=source.get_h() || isnan(u) || isnan(v))
+				if(u<0 || v<0 || u>=source.get_w() || v>=source.get_h() || std::isnan(u) || std::isnan(v))
 					(*surface)[y][x]=context.get_color(tmp);
 				else
 					//pen.set_value(source[v][u]);
@@ -977,8 +1130,8 @@ Warp::accelerated_cairorender(Context context, cairo_t *cr, int quality, const R
 	 ;
 	 swap(tl[1],br[1]);*/
 	
-	//synfig::warning("given window: [%f,%f]-[%f,%f] %dx%d",tl[0],tl[1],br[0],br[1],renddesc.get_w(),renddesc.get_h());
-	//synfig::warning("Projected: [%f,%f]-[%f,%f]",bounding_rect.get_min()[0],bounding_rect.get_min()[1],bounding_rect.get_max()[0],bounding_rect.get_max()[1]);
+	//warning("given window: [%f,%f]-[%f,%f] %dx%d",tl[0],tl[1],br[0],br[1],renddesc.get_w(),renddesc.get_h());
+	//warning("Projected: [%f,%f]-[%f,%f]",bounding_rect.get_min()[0],bounding_rect.get_min()[1],bounding_rect.get_max()[0],bounding_rect.get_max()[1]);
 	
 	// If we are clipping, then go ahead and clip to the
 	// source rectangle
@@ -1034,7 +1187,7 @@ Warp::accelerated_cairorender(Context context, cairo_t *cr, int quality, const R
 	desc.set_br(br);
 	desc.set_wh(ceil_to_int(src_pw*(br[0]-tl[0])),ceil_to_int(src_ph*(br[1]-tl[1])));
 	
-	//synfig::warning("surface to render: [%f,%f]-[%f,%f] %dx%d",desc.get_tl()[0],desc.get_tl()[1],desc.get_br()[0],desc.get_br()[1],desc.get_w(),desc.get_h());
+	//warning("surface to render: [%f,%f]-[%f,%f] %dx%d",desc.get_tl()[0],desc.get_tl()[1],desc.get_br()[0],desc.get_br()[1],desc.get_w(),desc.get_h());
 	if(desc.get_w()==0 && desc.get_h()==0)
 	{
 		cairo_save(cr);
@@ -1094,7 +1247,7 @@ Warp::accelerated_cairorender(Context context, cairo_t *cr, int quality, const R
 				u=(tmp[0]-tl[0])*src_pw;
 				v=(tmp[1]-tl[1])*src_ph;
 				
-				if(u<0 || v<0 || u>=sourcew || v>=sourceh || isnan(u) || isnan(v))
+				if(u<0 || v<0 || u>=sourcew || v>=sourceh || std::isnan(u) || std::isnan(v))
 					csurface[y][x]=context.get_cairocolor(tmp);
 				else
 				{
@@ -1139,13 +1292,13 @@ Warp::accelerated_cairorender(Context context, cairo_t *cr, int quality, const R
 	return true;
 }
 
-synfig::Rect
+Rect
 Warp::get_bounding_rect()const
 {
 	return Rect::full_plane();
 }
 
-synfig::Rect
+Rect
 Warp::get_full_bounding_rect(Context context)const
 {
 //	return Rect::full_plane();
