@@ -31,8 +31,15 @@
 #	include <config.h>
 #endif
 
+#include <cstring>
+
+#include <ETL/pen>
+
 #include "blur.h"
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -44,8 +51,9 @@
 #include <synfig/segment.h>
 #include <synfig/cairo_renddesc.h>
 
-#include <cstring>
-#include <ETL/pen>
+#include <synfig/rendering/common/task/taskblend.h>
+#include <synfig/rendering/common/task/taskblur.h>
+#include <synfig/rendering/software/function/blur.h>
 
 #endif
 
@@ -68,7 +76,7 @@ SYNFIG_LAYER_INIT(Blur_Layer);
 SYNFIG_LAYER_SET_NAME(Blur_Layer,"blur");
 SYNFIG_LAYER_SET_LOCAL_NAME(Blur_Layer,N_("Blur"));
 SYNFIG_LAYER_SET_CATEGORY(Blur_Layer,N_("Blurs"));
-SYNFIG_LAYER_SET_VERSION(Blur_Layer,"0.2");
+SYNFIG_LAYER_SET_VERSION(Blur_Layer,"0.3");
 SYNFIG_LAYER_SET_CVS_ID(Blur_Layer,"$Id$");
 
 /* -- F U N C T I O N S ----------------------------------------------------- */
@@ -80,7 +88,7 @@ inline void clamp(synfig::Vector &v)
 }
 
 Blur_Layer::Blur_Layer():
-	Layer_Composite(1.0,Color::BLEND_STRAIGHT),
+	Layer_CompositeFork(1.0,Color::BLEND_STRAIGHT),
 	param_size(ValueBase(Point(0.1,0.1))),
 	param_type(ValueBase(int(Blur::FASTGAUSSIAN)))
 {
@@ -120,6 +128,8 @@ Blur_Layer::get_color(Context context, const Point &pos)const
 {
 	synfig::Point size=param_size.get(Point());
 	int type=param_type.get(int());
+  	size *= rendering::software::Blur::get_size_amplifier((rendering::Blur::Type)type)
+  	      * ::Blur::get_size_amplifier(type);
 	
 	Point blurpos = Blur(size,type)(pos);
 
@@ -139,6 +149,8 @@ Blur_Layer::accelerated_render(Context context,Surface *surface,int quality, con
 
 	synfig::Point size=param_size.get(Point());
 	int type=param_type.get(int());
+  	size *= rendering::software::Blur::get_size_amplifier((rendering::Blur::Type)type)
+  	      * ::Blur::get_size_amplifier(type);
 
 	// don't do anything at quality 10
 	if (quality == 10)
@@ -248,6 +260,22 @@ Blur_Layer::accelerated_render(Context context,Surface *surface,int quality, con
 		return false;
 	}
 
+	// check size
+	for(int i = surface->get_w()-2; i; --i)
+	{
+		Real a0 = (*surface)[0][i].get_a();
+		Real a1 = (*surface)[0][i+1].get_a();
+		if (type == 2) a0*=2.0, a1*=2.0;
+		if (a0 > 0.25) {
+			Real d = (a1 - a0);
+			Real p = fabs(d) > 1e-10 ? (a0 - 0.25)/d : 0.0;
+			p += i - 200;
+			Real pw = (Real)workdesc.get_w()/(workdesc.get_br()[0]-workdesc.get_tl()[0]);
+			info("legacy type %d size %f actual size %f", type, size[0]*pw, p);
+			break;
+		}
+	}
+
 	return true;
 }
 
@@ -257,6 +285,8 @@ Blur_Layer::accelerated_cairorender(Context context, cairo_t *cr, int quality, c
 {
 	synfig::Point size=param_size.get(Point());
 	int type=param_type.get(int());
+  	size *= rendering::software::Blur::get_size_amplifier((rendering::Blur::Type)type)
+  	      * ::Blur::get_size_amplifier(type);
 
 	// don't do anything at quality 10
 	if (quality == 10)
@@ -433,6 +463,9 @@ Rect
 Blur_Layer::get_full_bounding_rect(Context context)const
 {
 	synfig::Point size=param_size.get(Point());
+	int type=param_type.get(int());
+  	size *= rendering::software::Blur::get_size_amplifier((rendering::Blur::Type)type)
+  	      * ::Blur::get_size_amplifier(type);
 
 	if(is_disabled() || Color::is_onto(get_blend_method()))
 		return context.get_full_bounding_rect();
@@ -441,3 +474,17 @@ Blur_Layer::get_full_bounding_rect(Context context)const
 
 	return bounds;
 }
+
+rendering::Task::Handle
+Blur_Layer::build_composite_fork_task_vfunc(ContextParams /* context_params */, rendering::Task::Handle sub_task)const
+{
+	Vector size = param_size.get(Point());
+	rendering::Blur::Type type = (rendering::Blur::Type)param_type.get(int());
+
+	rendering::TaskBlur::Handle task_blur(new rendering::TaskBlur());
+	task_blur->blur.size = size;
+	task_blur->blur.type = type;
+	task_blur->sub_task() = sub_task->clone_recursive();
+
+	return task_blur;
+}
