@@ -86,26 +86,26 @@ public:
 	};
 
 	Advanced_Outline();
-	//! Updates the polygon data to match the parameters.
-	void sync();
+
+	virtual bool set_shape_param(const String & param, const synfig::ValueBase &value);
 	virtual bool set_param(const String & param, const synfig::ValueBase &value);
 	virtual ValueBase get_param(const String & param)const;
 	virtual Vocab get_param_vocab()const;
-	using Layer::set_time;
-	virtual void set_time(IndependentContext context, Time time)const;
-	virtual void set_time(IndependentContext context, Time time, Vector pos)const;
 	virtual bool set_version(const synfig::String &ver);
+
 	//! Connects the parameter to another Value Node. Implementation for this layer
 	virtual bool connect_dynamic_param(const String& param, etl::loose_handle<ValueNode> x );
 
 private:
-
 	bool connect_bline_to_wplist(etl::loose_handle<ValueNode> x);
 	bool connect_bline_to_dilist(etl::loose_handle<ValueNode> x);
 	Real bline_to_bezier(Real bline_pos, Real origin, Real bezier_size);
 	Real bezier_to_bline(Real bezier_pos, Real origin, Real bezier_size);
 	void add_tip(std::vector<Point> &side_a, std::vector<Point> &side_b, const Point vertex, const Vector tangent, const WidthPoint wp, const Real gv);
 	void add_cusp(std::vector<Point> &side_a, std::vector<Point> &side_b, const Point vertex, const Vector curr, const Vector last, Real width);
+
+protected:
+	virtual void sync_vfunc();
 };
 
 /* === E N D =============================================================== */
