@@ -69,27 +69,21 @@ private:
 
 	bool needs_sync;
 
-
 	std::vector<synfig::Segment> segment_list;
 	std::vector<synfig::Real> width_list;
 
 public:
-
 	Outline();
 
-	//! Updates the polygon data to match the parameters.
-	void sync();
-
+	virtual bool set_shape_param(const String & param, const synfig::ValueBase &value);
 	virtual bool set_param(const String & param, const synfig::ValueBase &value);
-
 	virtual ValueBase get_param(const String & param)const;
-
 	virtual Vocab get_param_vocab()const;
-	using Layer::set_time;
-	virtual void set_time(IndependentContext context, Time time)const;
-	virtual void set_time(IndependentContext context, Time time, Vector pos)const;
 	virtual bool set_version(const String &ver){if(ver=="0.1")old_version=true; return true;}
 	virtual void reset_version(){old_version=false;}
+
+protected:
+	virtual void sync_vfunc();
 };
 
 /* === E N D =============================================================== */
