@@ -47,28 +47,24 @@ using namespace synfig;
 using namespace std;
 using namespace etl;
 
-class Region : protected synfig::Layer_Polygon//Shape
+class Region : protected synfig::Layer_Polygon
 {
 	SYNFIG_LAYER_MODULE_EXT
 private:
 	//! Parameter: list of type BlinePoint
 	ValueBase param_bline;
-
 	std::vector<synfig::Segment> segment_list;
+
 public:
 	Region();
 
-	//! Updates the polygon data to match the parameters.
-	void sync();
-
+	virtual bool set_shape_param(const String & param, const synfig::ValueBase &value);
 	virtual bool set_param(const String & param, const synfig::ValueBase &value);
-
 	virtual ValueBase get_param(const String & param)const;
-
 	virtual Vocab get_param_vocab()const;
-	using Layer::set_time;
-	virtual void set_time(IndependentContext context, Time time)const;
-	virtual void set_time(IndependentContext context, Time time, Vector pos)const;
+
+protected:
+	virtual void sync_vfunc();
 };
 
 /* === E N D =============================================================== */
