@@ -30,6 +30,9 @@
 #	include <config.h>
 #endif
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -235,6 +238,8 @@ ConicalGradient::get_color(Context context, const Point &pos)const
 bool
 ConicalGradient::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
+
 	SuperCallback supercb(cb,0,9500,10000);
 
 	if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
