@@ -34,6 +34,9 @@
 #	include <config.h>
 #endif
 
+#include <synfig/listimporter.h>
+#include <synfig/general.h>
+
 #include "trgt_mng.h"
 #include <libmng.h>
 #include <ETL/stringf>
@@ -152,7 +155,7 @@ mng_trgt::set_rend_desc(RendDesc *given_desc)
 
 
 bool
-mng_trgt::init(synfig::ProgressCallback *cb)
+mng_trgt::init(synfig::ProgressCallback * /* cb */)
 {
 	// synfig::info("%s:%d mng_trgt::init()", __FILE__, __LINE__);
 
