@@ -87,7 +87,7 @@ public:
 	virtual ~mng_trgt();
 
 	virtual bool set_rend_desc(synfig::RendDesc *desc);
-	virtual bool init();
+	virtual bool init(synfig::ProgressCallback *cb);
 	virtual bool start_frame(synfig::ProgressCallback *cb);
 	virtual void end_frame();
 
