@@ -33,6 +33,9 @@
 
 #include "distort.h"
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/string.h>
 #include <synfig/time.h>
 #include <synfig/context.h>
@@ -65,7 +68,7 @@ SYNFIG_LAYER_SET_CVS_ID(NoiseDistort,"$Id$");
 /* === M E T H O D S ======================================================= */
 
 NoiseDistort::NoiseDistort():
-	Layer_Composite(1.0,Color::BLEND_STRAIGHT),
+	Layer_CompositeFork(1.0,Color::BLEND_STRAIGHT),
 	param_displacement(ValueBase(Vector(0.25,0.25))),
 	param_size(ValueBase(Vector(1,1))),
 	param_random(ValueBase(int(time(NULL)))),
@@ -94,8 +97,7 @@ NoiseDistort::point_func(const Point &point)const
 	float y(point[1]/size[1]*(1<<detail));
 	
 	int i;
-	Time time;
-	time=speed*curr_time;
+	Time time = speed*get_time_mark();
 	int temp_smooth(smooth_);
 	int smooth((!speed && temp_smooth == (int)(RandomNoise::SMOOTH_SPLINE)) ? (int)(RandomNoise::SMOOTH_FAST_SPLINE) : temp_smooth);
 	
@@ -152,20 +154,6 @@ NoiseDistort::calc_supersample(const synfig::Point &/*x*/, float /*pw*/,float /*
 	return 0.0f;
 }
 
-void
-NoiseDistort::set_time(synfig::IndependentContext context, synfig::Time t)const
-{
-	curr_time=t;
-	context.set_time(t);
-}
-
-void
-NoiseDistort::set_time(synfig::IndependentContext context, synfig::Time t, const synfig::Point &point)const
-{
-	curr_time=t;
-	context.set_time(t,point);
-}
-
 synfig::Layer::Handle
 NoiseDistort::hit_check(synfig::Context context, const synfig::Point &point)const
 {
@@ -279,6 +267,28 @@ NoiseDistort::get_cairocolor(Context context, const Point &point)const
 		return CairoColor::blend(color,context.get_cairocolor(point),get_amount(),get_blend_method());
 }
 
+RendDesc
+NoiseDistort::get_sub_renddesc_vfunc(const RendDesc &renddesc) const
+{
+	Vector displacement=param_displacement.get(Vector());
+
+	RendDesc desc(renddesc);
+	Real pw = desc.get_pw();
+	Real ph = desc.get_ph();
+
+	Rect r(renddesc.get_tl(), renddesc.get_br());
+	r.expand_x(fabs(displacement[0]));
+	r.expand_y(fabs(displacement[1]));
+
+	desc.set_tl(r.get_min());
+	desc.set_br(r.get_max());
+	desc.set_wh(
+		(int)approximate_ceil(fabs((desc.get_br()[0] - desc.get_tl()[0])/pw)),
+		(int)approximate_ceil(fabs((desc.get_br()[1] - desc.get_tl()[1])/ph)) );
+
+	return desc;
+}
+
 Rect
 NoiseDistort::get_bounding_rect(Context context)const
 {
@@ -346,3 +356,7 @@ NoiseDistort::accelerated_render(Context context,Surface *surface,int quality, c
 	return true;
 }
 */
+
+rendering::Task::Handle
+NoiseDistort::build_rendering_task_vfunc(Context context) const
+	{ return Layer::build_rendering_task_vfunc(context); }
