@@ -31,7 +31,7 @@
 
 #include <synfig/vector.h>
 #include <synfig/valuenode.h>
-#include <synfig/layers/layer_composite.h>
+#include <synfig/layers/layer_composite_fork.h>
 #include <synfig/gradient.h>
 #include <synfig/time.h>
 #include "random_noise.h"
@@ -42,7 +42,7 @@
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
-class NoiseDistort : public synfig::Layer_Composite
+class NoiseDistort : public synfig::Layer_CompositeFork
 {
 	SYNFIG_LAYER_MODULE_EXT
 
@@ -62,9 +62,6 @@ private:
 	//!Parameter: (bool)
 	synfig::ValueBase param_turbulent;
 
-	//void sync();
-	mutable synfig::Time curr_time;
-
 	synfig::Color color_func(const synfig::Point &x, float supersample,synfig::Context context)const;
 	synfig::CairoColor cairocolor_func(const synfig::Point &x, float supersample,synfig::Context context)const;
 	synfig::Point point_func(const synfig::Point &point)const;
@@ -80,12 +77,14 @@ public:
 	virtual synfig::CairoColor get_cairocolor(synfig::Context context, const synfig::Point &pos)const;
 	//virtual bool accelerated_render(synfig::Context context,synfig::Surface *surface,int quality, const synfig::RendDesc &renddesc, synfig::ProgressCallback *cb)const;
 	synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
-	virtual void set_time(synfig::IndependentContext context, synfig::Time time)const;
-	virtual void set_time(synfig::IndependentContext context, synfig::Time time, const synfig::Point &point)const;
 	using Layer::get_bounding_rect;
 	virtual synfig::Rect get_bounding_rect(synfig::Context context)const;
 	virtual Vocab get_param_vocab()const;
 	virtual bool reads_context()const { return true; }
+
+protected:
+	virtual synfig::RendDesc get_sub_renddesc_vfunc(const synfig::RendDesc &renddesc) const;
+	virtual synfig::rendering::Task::Handle build_rendering_task_vfunc(synfig::Context context) const;
 }; // EOF of class NoiseDistort
 
 /* === E N D =============================================================== */
