@@ -31,6 +31,9 @@
 #	include <config.h>
 #endif
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/angle.h>
 #include "plant.h"
 #include <synfig/string.h>
@@ -280,7 +283,7 @@ Plant::sync()const
 			if((((i+1)*sprouts + steps/2) / steps) > branch_count) {
 				Vector branch_velocity(deriv(f).norm()*velocity + deriv(f).perp().norm()*perp_velocity);
 
-				if (isnan(branch_velocity[0]) || isnan(branch_velocity[1]))
+				if (std::isnan(branch_velocity[0]) || std::isnan(branch_velocity[1]))
 					continue;
 
 				branch_velocity[0] += random_factor * random(Random::SMOOTH_COSINE, 1, f*splits, 0.0f, 0.0f);
@@ -358,31 +361,7 @@ Plant::set_param(const String & param, const ValueBase &value)
 
 	return Layer_Composite::set_param(param,value);
 }
-/*
-void
-Plant::set_time(IndependentContext context, Time time)const
-{
-	if(needs_sync==true)
-	{
-		sync();
-		needs_sync_=false;
-	}
-	//const_cast<Plant*>(this)->sync();
-	context.set_time(time);
-}
 
-void
-Plant::set_time(IndependentContext context, Time time, Vector pos)const
-{
-	if(needs_sync==true)
-	{
-		sync();
-		needs_sync_=false;
-	}
-	//const_cast<Plant*>(this)->sync();
-	context.set_time(time,pos);
-}
-*/
 ValueBase
 Plant::get_param(const String& param)const
 {
@@ -595,7 +574,7 @@ Plant::draw_particles(Surface *dest_surface, const RendDesc &renddesc)const
 	const Real pw = (br[0] - tl[0]) / w;
 	const Real ph = (br[1] - tl[1]) / h;
 	
-	if (isinf(pw) || isinf(ph))
+	if (std::isinf(pw) || std::isinf(ph))
 		return;
 	
 	if (particle_list.begin() != particle_list.end())
