@@ -32,6 +32,9 @@
 #	include <config.h>
 #endif
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include "trgt_png.h"
 #include <png.h>
 #include <ETL/stringf>
