@@ -31,12 +31,17 @@
 #endif
 
 #include "gradient.h"
-#include "general.h"
-#include <stdexcept>
-#include "exception.h"
+
 #include <algorithm>
+#include <stdexcept>
 
 #include <ETL/misc>
+
+#include "general.h"
+#include <synfig/localization.h>
+
+#include "exception.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -327,7 +332,7 @@ synfig::Gradient::operator()(const Real &x,float supersample)const
 	float begin_sample(x-supersample*0.5);
 	float end_sample(x+supersample*0.5);
 
-	if(cpoints.size()==1 || end_sample<=cpoints.front().pos || isnan(x))
+	if(cpoints.size()==1 || end_sample<=cpoints.front().pos || std::isnan(x))
 		return cpoints.front().color;
 
 	if(begin_sample>=cpoints.back().pos)
