@@ -30,15 +30,25 @@
 #	include <config.h>
 #endif
 
+#include <cctype>
+#include <cstdlib>
+
+#include <algorithm>
+#include <functional>
+#include <map>
+
+#include <glibmm.h>
+
+#include "general.h"
+#include <synfig/localization.h>
+
 #include "canvas.h"
 #include "importer.h"
-#include "surface.h"
-#include <algorithm>
 #include "string.h"
-#include <map>
-#include <ctype.h>
-#include <functional>
-#include <glibmm.h>
+#include "surface.h"
+
+#include <synfig/rendering/software/surfacesw.h>
+#include <synfig/rendering/software/surfaceswpacked.h>
 
 #endif
 
@@ -144,3 +154,28 @@ Importer::~Importer()
 			__open_importers->erase(iter);
 		}
 }
+
+rendering::Surface::Handle
+Importer::get_frame(const RendDesc & /* renddesc */, const Time &time)
+{
+	if (last_surface_ && last_surface_->is_created())
+		return last_surface_;
+
+	Surface surface;
+	bool trimmed = false;
+	unsigned int width = 0, height = 0, top = 0, left = 0;
+	if(!get_frame(surface, RendDesc(), time, trimmed, width, height, top, left))
+		warning(strprintf("Unable to get frame from \"%s\"", identifier.filename.c_str()));
+
+
+	const char *s = getenv("SYNFIG_PACK_IMAGES");
+	if (s == NULL || atoi(s) != 0)
+		last_surface_ = new rendering::SurfaceSWPacked();
+	else
+		last_surface_ = new rendering::SurfaceSW();
+
+	if (surface.is_valid())
+		last_surface_->assign(surface[0], surface.get_w(), surface.get_h());
+
+	return last_surface_;
+}
