@@ -31,33 +31,40 @@
 #	include <config.h>
 #endif
 
-#include "canvas.h"
-#include "layer.h"
-#include "render.h"
-#include "value.h"
-#include <synfig/layers/layer_bitmap.h>
-#include <synfig/layers/layer_mime.h>
-#include "context.h"
-#include "paramdesc.h"
-#include "surface.h"
+#include <sigc++/adaptors/bind.h>
 
-#include <synfig/layers/layer_solidcolor.h>
-#include <synfig/layers/layer_polygon.h>
-#include <synfig/layers/layer_group.h>
-#include <synfig/layers/layer_switch.h>
-#include <synfig/layers/layer_motionblur.h>
-#include <synfig/layers/layer_duplicate.h>
-#include <synfig/layers/layer_skeleton.h>
-#include <synfig/layers/layer_skeletondeformation.h>
-#include <synfig/layers/layer_sound.h>
+#include "layer.h"
+
+#include "general.h"
+#include <synfig/localization.h>
+#include "rect.h"
+#include "guid.h"
+#include "value.h"
+#include "render.h"
+#include "canvas.h"
+#include "context.h"
+#include "surface.h"
+#include "paramdesc.h"
+#include "transform.h"
+
+#include "layers/layer_composite.h"
+#include "layers/layer_bitmap.h"
+#include "layers/layer_duplicate.h"
+#include "layers/layer_group.h"
+#include "layers/layer_mime.h"
+#include "layers/layer_motionblur.h"
+#include "layers/layer_polygon.h"
+#include "layers/layer_skeleton.h"
+#include "layers/layer_skeletondeformation.h"
+#include "layers/layer_solidcolor.h"
+#include "layers/layer_sound.h"
+#include "layers/layer_switch.h"
 
 #include "valuenodes/valuenode_const.h"
 
-#include "transform.h"
-#include "rect.h"
-#include "guid.h"
+#include "rendering/common/task/tasklayer.h"
+#include "rendering/common/task/tasksurfaceempty.h"
 
-#include <sigc++/adaptors/bind.h>
 #endif
 
 /* === U S I N G =========================================================== */
@@ -154,7 +161,8 @@ Layer::Layer():
 	optimized_(false),
 	exclude_from_rendering_(false),
 	param_z_depth(Real(0.0f)),
-	dirty_time_(Time::end())
+	time_mark(Time::end()),
+	outline_grow_mark(0.0)
 {
 	_LayerCounter::counter++;
 	SET_INTERPOLATION_DEFAULTS();
@@ -176,6 +184,7 @@ synfig::Layer::create(const String &name)
 synfig::Layer::~Layer()
 {
 	_LayerCounter::counter--;
+
 	while(!dynamic_param_list_.empty())
 	{
 		remove_child(dynamic_param_list_.begin()->second.get());
@@ -213,8 +222,16 @@ synfig::Layer::set_canvas(etl::loose_handle<Canvas> x)
 
 void
 synfig::Layer::on_canvas_set()
-{
-}
+	{ }
+
+void
+synfig::Layer::on_static_param_changed(const String & /* param */)
+	{ }
+
+void
+synfig::Layer::on_dynamic_param_changed(const String & /* param */)
+	{ }
+
 
 etl::loose_handle<synfig::Canvas>
 synfig::Layer::get_canvas()const
@@ -264,39 +281,39 @@ Layer::set_description(const String& x)
 	}
 }
 
-bool
-Layer::connect_dynamic_param(const String& param, etl::loose_handle<ValueNode> value_node)
+void
+Layer::static_param_changed(const String &param)
 {
-	ValueNode::Handle previous(dynamic_param_list_[param]);
+	on_static_param_changed(param);
+	if (!dynamic_param_list().count(param))
+		signal_static_param_changed_(param);
+}
 
-	if(previous==value_node)
-		return true;
-
-	dynamic_param_list_[param]=ValueNode::Handle(value_node);
-
-	if(previous)
-		remove_child(previous.get());
-
-	add_child(value_node.get());
-
-	if(!value_node->is_exported() && get_canvas())
-	{
-		value_node->set_parent_canvas(get_canvas());
-	}
-
-	changed();
-	return true;
+void
+Layer::dynamic_param_changed(const String &param)
+{
+	on_dynamic_param_changed(param);
+	if (!dynamic_param_list().count(param))
+		signal_dynamic_param_changed_(param);
 }
 
 bool
-Layer::disconnect_dynamic_param(const String& param)
+Layer::connect_dynamic_param(const String& param, etl::loose_handle<ValueNode> value_node)
 {
-	ValueNode::Handle previous(dynamic_param_list_[param]);
+	if (!value_node) return disconnect_dynamic_param(param);
 
-	if(previous)
+	ValueNode::Handle previous;
+	DynamicParamList::iterator i = dynamic_param_list_.find(param);
+	if (i != dynamic_param_list_.end()) previous = i->second;
+
+	if (previous == value_node)
+		return true;
+
+	String param_noref = param;
+	dynamic_param_list_[param]=ValueNode::Handle(value_node);
+
+	if (previous)
 	{
-		dynamic_param_list_.erase(param);
-
 		// fix 2353284: if two parameters in the same layer are
 		// connected to the same valuenode and we disconnect one of
 		// them, the parent-child relationship for the remaining
@@ -308,9 +325,44 @@ Layer::disconnect_dynamic_param(const String& param)
 				break;
 		if (iter == dynamic_param_list().end())
 			remove_child(previous.get());
-
-		changed();
 	}
+
+	add_child(value_node.get());
+	if(!value_node->is_exported() && get_canvas())
+		value_node->set_parent_canvas(get_canvas());
+
+	dynamic_param_changed(param);
+	changed();
+	return true;
+}
+
+bool
+Layer::disconnect_dynamic_param(const String& param)
+{
+	DynamicParamList::iterator i = dynamic_param_list_.find(param);
+	if (i == dynamic_param_list_.end()) return true;
+
+	ValueNode::Handle previous(i->second);
+	dynamic_param_list_.erase(i);
+
+	if(previous)
+	{
+		// fix 2353284: if two parameters in the same layer are
+		// connected to the same valuenode and we disconnect one of
+		// them, the parent-child relationship for the remaining
+		// connection was being deleted.  now we search the parameter
+		// list to see if another parameter uses the same valuenode
+		DynamicParamList::const_iterator iter;
+		for (iter = dynamic_param_list().begin(); iter != dynamic_param_list().end(); iter++)
+			if (iter->second == previous)
+				break;
+		if (iter == dynamic_param_list().end())
+			remove_child(previous.get());
+	}
+
+	static_param_changed(param);
+	changed();
+
 	return true;
 }
 
@@ -320,10 +372,23 @@ Layer::on_changed()
 	if (getenv("SYNFIG_DEBUG_ON_CHANGED"))
 		printf("%s:%d Layer::on_changed()\n", __FILE__, __LINE__);
 
-	dirty_time_=Time::end();
+	clear_time_mark();
 	Node::on_changed();
 }
 
+void
+Layer::on_child_changed(const Node *x)
+{
+	Node::on_child_changed(x);
+	for(DynamicParamList::const_iterator i = dynamic_param_list().begin(); i != dynamic_param_list().end();)
+	{
+		DynamicParamList::const_iterator j = i;
+		++i;
+		if (j->second.get() == x)
+			dynamic_param_changed(j->first);
+	}
+}
+
 bool
 Layer::set_param(const String &param, const ValueBase &value)
 {
@@ -352,6 +417,13 @@ Layer::get_true_z_depth(const synfig::Time& t)const
 	return get_z_depth(t)*1.0001+get_depth();
 }
 
+float
+Layer::get_true_z_depth()const
+{
+	// TODO: the 1.0001 constant should be somehow user defined
+	return get_z_depth()*1.0001+get_depth();
+}
+
 Layer::Handle
 Layer::simple_clone()const
 {
@@ -385,6 +457,9 @@ Layer::clone(Canvas::LooseHandle canvas, const GUID& deriv_guid) const
 	ret->set_exclude_from_rendering(get_exclude_from_rendering());
 	ret->set_guid(get_guid()^deriv_guid);
 
+	ret->set_time_mark(get_time_mark());
+	ret->set_outline_grow_mark(get_outline_grow_mark());
+
 	//ret->set_param_list(get_param_list());
 	// Process the parameter list so that
 	// we can duplicate any inline canvases
@@ -514,22 +589,42 @@ Layer::set_version(const String &/*ver*/)
 
 void
 Layer::reset_version()
-{
-}
+	{ }
 
 
 void
 Layer::set_time(IndependentContext context, Time time)const
 {
-	context.set_time(time);
-	dirty_time_=time;
+	Layer::ParamList params;
+	Layer::DynamicParamList::const_iterator iter;
+	// For each parameter of the layer sets the time by the operator()(time)
+	for(iter=dynamic_param_list().begin();iter!=dynamic_param_list().end();iter++)
+		params[iter->first]=(*iter->second)(time);
+	// Sets the modified parameter list to the current context layer
+	const_cast<Layer*>(this)->set_param_list(params);
+
+	set_time_mark(time);
+
+	set_time_vfunc(context, time);
 }
 
 void
-Layer::set_time(IndependentContext context, Time time, const Point &pos)const
+Layer::set_time_vfunc(IndependentContext context, Time time)const
 {
-	context.set_time(time,pos);
-	dirty_time_=time;
+	context.set_time(time);
+}
+
+void
+Layer::set_outline_grow(IndependentContext context, Real outline_grow)const
+{
+	set_outline_grow_mark(outline_grow);
+	set_outline_grow_vfunc(context, outline_grow);
+}
+
+void
+Layer::set_outline_grow_vfunc(IndependentContext context, Real outline_grow)const
+{
+	context.set_outline_grow(outline_grow);
 }
 
 void
@@ -730,7 +825,7 @@ Layer::accelerated_render(Context context,Surface *surface,int quality, const Re
 {
 	RENDER_TRANSFORMED_IF_NEED(__FILE__, __LINE__)
 
-	handle<Target_Scanline> target=surface_target(surface);
+	handle<Target_Scanline> target=surface_target_scanline(surface);
 	if(!target)
 	{
 		if(cb)cb->error(_("Unable to create surface target"));
@@ -768,6 +863,59 @@ Layer::accelerated_cairorender(Context context, cairo_t *cr, int /*quality*/, co
 	return cairorender(context,cr,renddesc,cb);
 }
 
+RendDesc
+Layer::get_sub_renddesc_vfunc(const RendDesc &renddesc) const
+{
+	return renddesc;
+}
+
+void
+Layer::get_sub_renddesc_vfunc(const RendDesc &renddesc, std::vector<RendDesc> &out_descs) const
+{
+	out_descs.push_back( get_sub_renddesc_vfunc(renddesc) );
+}
+
+void
+Layer::get_sub_renddesc(const RendDesc &renddesc, std::vector<RendDesc> &out_descs) const
+{
+	get_sub_renddesc_vfunc(renddesc, out_descs);
+}
+
+RendDesc
+Layer::get_sub_renddesc(const RendDesc &renddesc, int index) const
+{
+	std::vector<RendDesc> descs;
+	get_sub_renddesc(renddesc, descs);
+	return index >=0 && index < (int)descs.size() ? descs[index] : RendDesc::zero();
+}
+
+rendering::Task::Handle
+Layer::build_rendering_task_vfunc(Context context)const
+{
+	rendering::TaskLayer::Handle task = new rendering::TaskLayer();
+	// TODO: This is not thread-safe
+	//task->layer = const_cast<Layer*>(this);//clone(NULL);
+	task->layer = clone(NULL);
+	task->layer->set_canvas(get_canvas());
+
+	Real amount = Context::z_depth_visibility(context.get_params(), *this);
+	if (approximate_not_equal(amount, 1.0) && task->layer.type_is<Layer_Composite>())
+	{
+		//task->layer = task->layer->clone(NULL);
+		etl::handle<Layer_Composite> composite = etl::handle<Layer_Composite>::cast_dynamic(task->layer);
+		composite->set_amount( composite->get_amount()*amount );
+	}
+
+	task->sub_task() = context.build_rendering_task();
+	return task;
+}
+
+rendering::Task::Handle
+Layer::build_rendering_task(Context context)const
+{
+	rendering::Task::Handle task = build_rendering_task_vfunc(context);
+	return task ? task : rendering::Task::Handle(new rendering::TaskSurfaceEmpty());
+}
 
 String
 Layer::get_name()const
@@ -886,22 +1034,6 @@ Layer::get_string()const
 
 }
 
-Real
-Layer::get_parent_canvas_grow_value()const
-{
-	Canvas::Handle parent_canvas(get_canvas());
-	Real ret;
-	if(parent_canvas)
-	{
-		ret=parent_canvas->get_grow_value();
-	}
-	else
-	{
-		ret=0.0;
-	}
-	return ret;
-}
-
 void
 Layer::fill_sound_processor(SoundProcessor & /* soundProcessor */) const
-{ }
+	{ }
