@@ -33,17 +33,25 @@
 #endif
 
 #include "layer_pastecanvas.h"
-#include "string.h"
-#include "time.h"
-#include "../context.h"
-#include "../paramdesc.h"
-#include "../renddesc.h"
-#include "../surface.h"
-#include "../value.h"
-#include "../valuenode.h"
-#include "../canvas.h"
-#include "../cairo_renddesc.h"
 
+#include <synfig/general.h>
+#include <synfig/localization.h>
+
+#include <synfig/cairo_renddesc.h>
+#include <synfig/canvas.h>
+#include <synfig/context.h>
+#include <synfig/paramdesc.h>
+#include <synfig/renddesc.h>
+#include <synfig/time.h>
+#include <synfig/string.h>
+#include <synfig/surface.h>
+#include <synfig/value.h>
+#include <synfig/valuenode.h>
+
+#include <synfig/rendering/common/task/taskblend.h>
+#include <synfig/rendering/common/task/tasksurfaceempty.h>
+#include <synfig/rendering/common/task/tasktransformation.h>
+#include <synfig/rendering/primitive/affinetransformation.h>
 
 #endif
 
@@ -81,17 +89,13 @@ public:
 Layer_PasteCanvas::Layer_PasteCanvas():
 	param_origin(Point()),
 	param_transformation(Transformation()),
-	param_time_dilation (Real(1)),
-	param_time_offset (Time(0)),
+	param_time_dilation(Real(1)),
+	param_time_offset(Time(0)),
+	param_outline_grow(Real(0)),
+	param_children_lock(bool(false)),
 	depth(0),
 	extra_reference(false)
 {
-	param_children_lock=ValueBase(bool(false));
-	param_outline_grow=ValueBase(Real(0));
-	param_curr_time=ValueBase(Time::begin());
-
-	muck_with_time_=true;
-
 	SET_INTERPOLATION_DEFAULTS();
 	SET_STATIC_DEFAULTS();
 }
@@ -164,18 +168,6 @@ Layer_PasteCanvas::get_param_vocab()const
 		ret.back().hidden();
 	}
 
-	// optimize_layers() in canvas.cpp makes a new PasteCanvas layer
-	// and copies over the parameters of the old layer.  the
-	// 'curr_time' member wasn't being copied, so I've added it as a
-	// hidden, non critical parameter, and now it will be.  this
-	// allows a single exported subcanvas to be used more than once at
-	// a time, with different time offets in each.  see bug #1896557.
-	ret.push_back(ParamDesc("curr_time")
-		.set_local_name(_("Current Time"))
-		.not_critical()
-		.hidden()
-	);
-
 	return ret;
 }
 
@@ -215,40 +207,44 @@ Layer_PasteCanvas::set_param(const String & param, const ValueBase &value)
 #endif
 
 	IMPORT_VALUE(param_children_lock);
-	IMPORT_VALUE(param_outline_grow);
-	IMPORT_VALUE(param_curr_time);
+	IMPORT_VALUE_PLUS(param_outline_grow,
+		if (canvas)
+		{
+			Real sub_outline_grow = param_outline_grow.get(Real());
+			canvas->set_outline_grow(get_outline_grow_mark() + sub_outline_grow);
+		}
+	);
 	return Layer_Composite::set_param(param,value);
 }
 
+void
+Layer_PasteCanvas::childs_changed()
+	{ on_childs_changed(); }
+
 void
 Layer_PasteCanvas::set_sub_canvas(etl::handle<synfig::Canvas> x)
 {
-	if(canvas && muck_with_time_)
+	if (canvas)
 		remove_child(canvas.get());
 
 	// if(canvas && (canvas->is_inline() || !get_canvas() || get_canvas()->get_root()!=canvas->get_root()))
 	if (extra_reference)
 		canvas->unref();
 
-	child_changed_connection.disconnect();
+	childs_changed_connection.disconnect();
 
 	if (canvas != x) signal_subcanvas_changed()();
 
 	canvas=x;
 
-	/*if(canvas)
-		child_changed_connection=canvas->signal_changed().connect(
-			sigc::mem_fun(
-				*this,
-				&Layer_PasteCanvas::changed
-			)
-		);
-	*/
+	if (canvas)
+		childs_changed_connection=canvas->signal_changed().connect(
+			sigc::mem_fun(*this, &Layer_PasteCanvas::childs_changed) );
 
-	if(canvas && muck_with_time_)
+	if (canvas)
 		add_child(canvas.get());
 
-	if(canvas && (canvas->is_inline() || !get_canvas() || get_canvas()->get_root()!=canvas->get_root()))
+	if (canvas && (canvas->is_inline() || !get_canvas() || get_canvas()->get_root()!=canvas->get_root()))
 	{
 		canvas->ref();
 		extra_reference = true;
@@ -256,7 +252,7 @@ Layer_PasteCanvas::set_sub_canvas(etl::handle<synfig::Canvas> x)
 	else
 		extra_reference = false;
 
-	if(canvas)
+	if (canvas)
 		on_canvas_set();
 }
 
@@ -301,29 +297,48 @@ Layer_PasteCanvas::get_param(const String& param)const
 	EXPORT_VALUE(param_time_dilation);
 	EXPORT_VALUE(param_time_offset);
 	EXPORT_VALUE(param_children_lock);
-	EXPORT_VALUE(param_curr_time);
 	EXPORT_VALUE(param_outline_grow);
 
 	return Layer_Composite::get_param(param);
 }
 
 void
-Layer_PasteCanvas::set_time(IndependentContext context, Time time)const
+Layer_PasteCanvas::set_time_vfunc(IndependentContext context, Time time)const
 {
-	Real time_dilation=param_time_dilation.get(Real());
-	Time time_offset=param_time_offset.get(Time());
-
-	if(depth==MAX_DEPTH)return;depth_counter counter(depth);
-	param_curr_time.set(time);
+	if (depth==MAX_DEPTH) return;
+	depth_counter counter(depth);
 
 	context.set_time(time);
-	if(canvas)
-		canvas->set_time(time*time_dilation+time_offset);
+	if (canvas)
+	{
+		Real time_dilation=param_time_dilation.get(Real());
+		Time time_offset=param_time_offset.get(Time());
+		canvas->set_time(time*time_dilation + time_offset);
+	}
 }
 
 void
-Layer_PasteCanvas::apply_z_range_to_params(ContextParams &/*cp*/)const
+Layer_PasteCanvas::set_outline_grow_vfunc(IndependentContext context, Real outline_grow)const
 {
+	if (depth==MAX_DEPTH) return;
+	depth_counter counter(depth);
+
+	context.set_outline_grow(outline_grow);
+	if (canvas)
+	{
+		Real sub_outline_grow = param_outline_grow.get(Real());
+		canvas->set_outline_grow(outline_grow + sub_outline_grow);
+	}
+}
+
+void
+Layer_PasteCanvas::apply_z_range_to_params(ContextParams &cp)const
+{
+	ContextParams p;
+	cp.z_range = p.z_range;
+	cp.z_range_position = p.z_range_position;
+	cp.z_range_depth = p.z_range_depth;
+	cp.z_range_blur = p.z_range_blur;
 }
 
 synfig::Layer::Handle
@@ -399,11 +414,6 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 		get_summary_transformation().get_matrix()
 	  * renddesc.get_transformation_matrix() );
 
-	Real outline_grow=param_outline_grow.get(Real());
-	Real time_dilation=param_time_dilation.get(Real());
-	Time time_offset=param_time_offset.get(Time());
-	Time curr_time=param_curr_time.get(Time());
-
 	if(cb && !cb->amount_complete(0,10000)) return false;
 
 	if(depth==MAX_DEPTH)
@@ -433,12 +443,6 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 	if (!context.accelerated_render(surface,quality,renddesc,&stageone))
 		return false;
 
-	Real grow_value(get_parent_canvas_grow_value());
-	canvas->set_grow_value(outline_grow+grow_value);
-
-	if(muck_with_time_ && curr_time!=Time::begin() /*&& canvas->get_time()!=curr_time+time_offset*/)
-		canvas->set_time(curr_time*time_dilation+time_offset);
-
 	Color::BlendMethod blend_method(get_blend_method());
 	const Rect full_bounding_rect(canvasContext.get_full_bounding_rect());
 
@@ -533,8 +537,20 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 		intermediate_desc.set_tl(pixel_aligned_tl);
 		intermediate_desc.set_br(pixel_aligned_br);
 		Surface intermediate_surface;
+
+		//{ // TODO: remove
+		//	std::ofstream of("/tmp/contours.txt", std::ios_base::app);
+		//	of << "g " << x0 << " " << y0 << endl;
+		//}
+
 		if(!canvasContext.accelerated_render(&intermediate_surface,quality,intermediate_desc,&stagetwo))
 			return false;
+
+		//{ // TODO: remove
+		//	std::ofstream of("/tmp/contours.txt", std::ios_base::app);
+		//	of << "end" << endl;
+		//}
+
 		Surface::alpha_pen apen(surface->get_pen(x0, y0));
 		apen.set_alpha(get_amount());
 		apen.set_blend_method(blend_using_straight ? Color::BLEND_STRAIGHT : blend_method);
@@ -552,11 +568,6 @@ Layer_PasteCanvas::accelerated_cairorender(Context context,cairo_t *cr, int qual
 {
 	Transformation transformation(get_summary_transformation());
 
-	Real outline_grow=param_outline_grow.get(Real());
-	Real time_dilation=param_time_dilation.get(Real());
-	Time time_offset=param_time_offset.get(Time());
-	Time curr_time=param_curr_time.get(Time());
-
 	if(cb && !cb->amount_complete(0,10000)) return false;
 
 	if(depth==MAX_DEPTH)
@@ -582,13 +593,6 @@ Layer_PasteCanvas::accelerated_cairorender(Context context,cairo_t *cr, int qual
 	if(!ret)
 		return false;
 
-	Real grow_value(get_parent_canvas_grow_value());
-	canvas->set_grow_value(outline_grow+grow_value);
-
-	if(muck_with_time_ && curr_time!=Time::begin() /*&& canvas->get_time()!=curr_time+time_offset*/)
-		canvas->set_time(curr_time*time_dilation+time_offset);
-
-
 	// render the canvas to be pasted onto pastesurface
 	cairo_surface_t* pastesurface=cairo_surface_create_similar_image(cairo_get_target(cr), CAIRO_FORMAT_ARGB32, workdesc.get_w(), workdesc.get_h());
 	cairo_t* subcr=cairo_create(pastesurface);
@@ -690,3 +694,24 @@ Layer_PasteCanvas::fill_sound_processor(SoundProcessor &soundProcessor) const
 {
 	if (active() && canvas) canvas->fill_sound_processor(soundProcessor);
 }
+
+rendering::Task::Handle
+Layer_PasteCanvas::build_composite_task_vfunc(ContextParams context_params) const
+{
+	if (!canvas)
+		return new rendering::TaskSurfaceEmpty();
+
+	CanvasBase sub_queue;
+	Context sub_context;
+	apply_z_range_to_params(context_params);
+	canvas->get_context_sorted(context_params, sub_queue, sub_context);
+
+	rendering::TaskTransformation::Handle task_transformation(new rendering::TaskTransformation());
+	rendering::AffineTransformation::Handle affine_transformation(new rendering::AffineTransformation());
+	affine_transformation->matrix = get_summary_transformation().get_matrix();
+	task_transformation->transformation = affine_transformation;
+	task_transformation->sub_task() = sub_context.build_rendering_task();
+	return task_transformation;
+}
+
+
