@@ -31,6 +31,9 @@
 #endif
 
 #include "paramdesc.h"
+
+#include "general.h"
+#include <synfig/localization.h>
 #include "value.h"
 
 #endif
@@ -49,6 +52,8 @@ using namespace synfig;
 
 /* === M E T H O D S ======================================================= */
 
+const ParamDesc ParamVocab::blank;
+
 ParamDesc::ParamDesc(const ValueBase&, const String &a):
 	name_			(a),
 	local_name_		(a),
