@@ -30,20 +30,26 @@
 #	include <config.h>
 #endif
 
-#ifndef WIN32
+#ifndef _WIN32
 #include <unistd.h>
 #include <sys/types.h>
 #include <signal.h>
 #endif
 
-#include "render.h"
-#include "target.h"
-#include "canvas.h"
-#include <ETL/handle>
 #include <cassert>
+
+#include <ETL/handle>
+
+#include "render.h"
+
+#include "general.h"
+#include <synfig/localization.h>
+
+#include "canvas.h"
+#include "cairo_renddesc.h"
 #include "context.h"
 #include "surface.h"
-#include "cairo_renddesc.h"
+#include "target.h"
 
 
 #endif
@@ -476,7 +482,7 @@ synfig::render_threaded(
 	ProgressCallback *callback,
 	int threads)
 {
-#ifndef WIN32
+#ifndef _WIN32
     struct _render_thread
     {
 		int
