@@ -31,12 +31,16 @@
 #endif
 
 #include "target_cairo.h"
-#include "string.h"
-#include "surface.h"
-#include "render.h"
+
+#include "general.h"
+#include <synfig/localization.h>
+
 #include "canvas.h"
 #include "context.h"
+#include "render.h"
 #include "rendermethod.h"
+#include "string.h"
+#include "surface.h"
 
 #endif
 
