@@ -36,6 +36,7 @@
 #include "valuenode_const.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 
 #endif
 
@@ -49,6 +50,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_And, RELEASE_VERSION_0_62_00, "and", "AND")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -118,17 +121,7 @@ ValueNode_And::operator()(Time t)const
 	return (link1 && link2);
 }
 
-String
-ValueNode_And::get_name()const
-{
-	return "and";
-}
 
-String
-ValueNode_And::get_local_name()const
-{
-	return _("AND");
-}
 
 bool
 ValueNode_And::check_type(Type &type)
