@@ -36,6 +36,7 @@
 #include "valuenode_const.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 
 #endif
 
@@ -49,6 +50,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_Compare, RELEASE_VERSION_0_62_00, "compare", "Compare")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -138,17 +141,7 @@ ValueNode_Compare::operator()(Time t)const
 	return false;
 }
 
-String
-ValueNode_Compare::get_name()const
-{
-	return "compare";
-}
 
-String
-ValueNode_Compare::get_local_name()const
-{
-	return _("Compare");
-}
 
 bool
 ValueNode_Compare::check_type(Type &type)
