@@ -35,6 +35,7 @@
 #include "valuenode_const.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 
 #endif
 
@@ -48,6 +49,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_Duplicate, RELEASE_VERSION_0_61_08, "duplicate", "Duplicate")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -164,17 +167,7 @@ ValueNode_Duplicate::operator()(Time t __attribute__ ((unused)))const
 	return index;
 }
 
-String
-ValueNode_Duplicate::get_name()const
-{
-	return "duplicate";
-}
 
-String
-ValueNode_Duplicate::get_local_name()const
-{
-	return _("Duplicate");
-}
 
 bool
 ValueNode_Duplicate::check_type(Type &type __attribute__ ((unused)))
