@@ -35,6 +35,7 @@
 #include "valuenode_const.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 
 #endif
 
@@ -48,6 +49,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_Logarithm, RELEASE_VERSION_0_61_09, "logarithm", "Logarithm")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -130,17 +133,7 @@ ValueNode_Logarithm::operator()(Time t)const
 		return log(link);
 }
 
-String
-ValueNode_Logarithm::get_name()const
-{
-	return "logarithm";
-}
 
-String
-ValueNode_Logarithm::get_local_name()const
-{
-	return _("Logarithm");
-}
 
 bool
 ValueNode_Logarithm::check_type(Type &type)
