@@ -36,6 +36,7 @@
 #include "valuenode_composite.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 #include <synfig/exception.h>
 #include <ETL/hermite>
 #include <ETL/calculus>
@@ -53,6 +54,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_SegCalcTangent, RELEASE_VERSION_0_61_06, "segcalctangent", "Segment Tangent")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -95,17 +98,7 @@ ValueNode_SegCalcTangent::operator()(Time t)const
 }
 
 
-String
-ValueNode_SegCalcTangent::get_name()const
-{
-	return "segcalctangent";
-}
 
-String
-ValueNode_SegCalcTangent::get_local_name()const
-{
-	return _("Segment Tangent");
-}
 
 bool
 ValueNode_SegCalcTangent::check_type(Type &type)
