@@ -37,6 +37,7 @@
 #include <synfig/boneweightpair.h>
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 #include <synfig/exception.h>
 #include <vector>
 #include <list>
@@ -56,6 +57,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_StaticList, RELEASE_VERSION_0_62_00, "static_list", "Static List")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -293,13 +296,13 @@ ValueNode_StaticList::~ValueNode_StaticList()
 }
 
 ValueNode_StaticList::Handle
-ValueNode_StaticList::create(Type &type, Canvas::LooseHandle canvas) // line 557
+ValueNode_StaticList::create_on_canvas(Type &type, Canvas::LooseHandle canvas)
 {
 	return new ValueNode_StaticList(type, canvas);
 }
 
 ValueNode_StaticList*
-ValueNode_StaticList::create_from(const ValueBase &value) // line 568
+ValueNode_StaticList::create(const ValueBase &value)
 {
 	vector<ValueBase> value_list(value.get_list());
 
@@ -434,17 +437,7 @@ ValueNode_StaticList::get_link_index_from_name(const String &name)const // line
 	throw Exception::BadLinkName(name);
 }
 
-String
-ValueNode_StaticList::get_name()const // line 705
-{
-	return "static_list";
-}
 
-String
-ValueNode_StaticList::get_local_name()const // line 711
-{
-	return _("Static List");
-}
 
 bool
 ValueNode_StaticList::check_type(Type &type) // line 717
@@ -484,7 +477,7 @@ ValueNode_StaticList::get_contained_type()const // line 730
 }
 
 LinkableValueNode*
-ValueNode_StaticList::create_new()const // line 736
+ValueNode_StaticList::create_new() const
 {
 	return new ValueNode_StaticList(*container_type);
 }
