@@ -34,6 +34,7 @@
 #include "valuenode_const.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 #include <synfig/color.h>
 #include <ETL/misc>
 
@@ -49,6 +50,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_Step, RELEASE_VERSION_0_61_08, "step", "Step")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -126,17 +129,7 @@ ValueNode_Step::operator()(Time t)const
 }
 
 
-String
-ValueNode_Step::get_name()const
-{
-	return "step";
-}
 
-String
-ValueNode_Step::get_local_name()const
-{
-	return _("Step");
-}
 
 bool
 ValueNode_Step::check_type(Type &type)
