@@ -33,6 +33,7 @@
 
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 #include "valuenode_subtract.h"
 #include "valuenode_const.h"
 #include <stdexcept>
@@ -55,6 +56,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_Subtract, RELEASE_VERSION_0_61_06, "subtract", "Subtract")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -192,17 +195,7 @@ ValueNode_Subtract::get_link_vfunc(int i)const
 	}
 }
 
-String
-ValueNode_Subtract::get_name()const
-{
-	return "subtract";
-}
 
-String
-ValueNode_Subtract::get_local_name()const
-{
-	return _("Subtract");
-}
 
 bool
 ValueNode_Subtract::check_type(Type &type)
