@@ -35,6 +35,7 @@
 #include "valuenode_const.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 
 #endif
 
@@ -48,6 +49,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_TimeLoop, RELEASE_VERSION_0_61_08, "timeloop", "Time Loop")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -142,17 +145,7 @@ ValueNode_TimeLoop::operator()(Time t)const
 	return (*link_)(t);
 }
 
-String
-ValueNode_TimeLoop::get_name()const
-{
-	return "timeloop";
-}
 
-String
-ValueNode_TimeLoop::get_local_name()const
-{
-	return _("Time Loop");
-}
 
 bool
 ValueNode_TimeLoop::check_type(Type &type)
