@@ -35,6 +35,7 @@
 #include "valuenode_const.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 
 #endif
 
@@ -48,6 +49,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_VectorAngle, RELEASE_VERSION_0_61_09, "vectorangle", "Vector Angle")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -113,17 +116,7 @@ ValueNode_VectorAngle::get_link_vfunc(int i)const
 	return 0;
 }
 
-String
-ValueNode_VectorAngle::get_name()const
-{
-	return "vectorangle";
-}
 
-String
-ValueNode_VectorAngle::get_local_name()const
-{
-	return _("Vector Angle");
-}
 
 bool
 ValueNode_VectorAngle::check_type(Type &type)
