@@ -1,3 +1,4 @@
+
 /* === S Y N F I G ========================================================= */
 /*!	\file waypoint.cpp
 **	\brief Template File
@@ -30,8 +31,8 @@
 #endif
 
 #include "waypoint.h"
-#include "valuenode_const.h"
-#include "valuenode_animated.h"
+#include "valuenodes/valuenode_const.h"
+#include "valuenodes/valuenode_animated.h"
 
 #endif
 
@@ -61,7 +62,7 @@ Waypoint::Waypoint(ValueBase value, Time time):
 	time_tension(0.0f)
 {
 	//!Writeme
-	if(value.get_type()==ValueBase::TYPE_ANGLE)
+	if(value.get_type()==type_angle)
 		after=before=INTERPOLATION_LINEAR;
 }
 
@@ -76,7 +77,7 @@ Waypoint::Waypoint(etl::handle<ValueNode> value_node, Time time):
 	bias(0),
 	time_tension(0.0f)
 {
-	if(value_node->get_type()==ValueBase::TYPE_ANGLE)
+	if(value_node->get_type()==type_angle)
 		after=before=INTERPOLATION_LINEAR;
 }
 
@@ -96,7 +97,7 @@ Waypoint::set_value(const ValueBase &x)
 {
 	//! If the value node is not set and we are seting the value
 	//! of an angle, then set both interpolation to linear... why?
-	if(!value_node && x.get_type()==ValueBase::TYPE_ANGLE)
+	if(!value_node && x.get_type()==type_angle)
 		after=before=INTERPOLATION_LINEAR;
 
 	value_node=ValueNode_Const::create(x);
@@ -111,7 +112,7 @@ Waypoint::set_value_node(const etl::handle<ValueNode> &x)
 	//! If the value node is not set and we are seting the value
 	//! of an angle, then set both interpolation to linear... why?
 
-	if(!value_node && x->get_type()==ValueBase::TYPE_ANGLE)
+	if(!value_node && x->get_type()==type_angle)
 		after=before=INTERPOLATION_LINEAR;
 
 	if (value_node == x)
