@@ -45,6 +45,9 @@
 
 #include <glibmm.h>
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+
 #include <synfig/module.h>
 #include <synfig/importer.h>
 #include <synfig/cairoimporter.h>
@@ -91,10 +94,7 @@ int main(int argc, char* argv[])
 	boost::filesystem::path locale_path =
 		binary_path.parent_path().parent_path();
 	locale_path = locale_path/"share"/"locale";
-#ifdef WIN32
-	locale_path = Glib::locale_from_utf8(locale_path.string());
-#endif
-	bindtextdomain("synfig", locale_path.string().c_str() );
+	bindtextdomain("synfig", Glib::locale_from_utf8(locale_path.string()).c_str() );
 	bind_textdomain_codeset("synfig", "UTF-8");
 	textdomain("synfig");
 #endif
